..
    This file is part of Invenio.
    Copyright (C) 2015-2020 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Installation
============

Invenio-Assets is on PyPI so all you need is:

.. code-block:: console

   $ pip install invenio-assets

Invenio-Assets depends on
`Flask-WebpackExt <https://flask-webpackext.readthedocs.io/en/latest/>`_
and `Flask-Collect <https://flask-collect.readthedocs.io/en/latest/>`_.
